#
# spec file for package python-yapf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-yapf
VCS: https://src.suse.de/SLFO-pool/python-yapf#601883dcad5d153f637b0668248cf3d6f7dfe3a70770def046626f0d859c34eb
Version:        0.40.2
Release:        160000.1.7
Summary:        A formatter for Python code
License:        Apache-2.0
URL:            https://github.com/google/yapf
Source:         https://files.pythonhosted.org/packages/source/y/yapf/yapf-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module platformdirs}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tomli}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-metadata
Requires:       python-platformdirs
Requires:       python-tomli
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
Recommends:     python-futures
%endif
%python_subpackages

%description
YAPF is based off clang-format and reformats it to the closest
formatting that conforms to the style guide, even if the original
code did not violate the style guide.

This is in contrast to other formatters like autopep8 and pep8ify
which are made to only remove lint errors from code, which has some
limitations, like, code that conforms to the PEP 8 guidelines may not
be reformatted.

%prep
%setup -q -n yapf-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/yapf
%python_clone -a %{buildroot}%{_bindir}/yapf-diff
%python_expand rm -r %{buildroot}%{$python_sitelib}/yapftests

%check
%pytest --capture=no

%post
%python_install_alternative yapf yapf-diff

%postun
%python_uninstall_alternative yapf

%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md
%python_alternative %{_bindir}/yapf
%python_alternative %{_bindir}/yapf-diff
%{python_sitelib}/yapf/
%{python_sitelib}/yapf_third_party/
%{python_sitelib}/yapf-%{version}.dist-info

%changelog
* Mon Mar 11 2024 steven.kowalik@suse.com
- Add missing {Build,}Requires on tomli and importlib-metadata.
* Mon Nov 27 2023 dmueller@suse.com
- update to 0.40.2:
  * The verification module has been removed. NOTE: this changes
    the public APIs by removing the "verify" parameter.
  * Changed FORCE_MULTILINE_DICT to override
    SPLIT_ALL_TOP_LEVEL_COMMA_SEPARATED_VALUES.
  * Adopt pyproject.toml (PEP 517) for build system
  * Do not treat variables named `match` as the match keyword.
  * Fix SPLIT_ARGUMENTS_WHEN_COMMA_TERMINATED for one-item
    argument lists.
  * Fix trailing backslash-newline on Windows when using stdin.
* Thu Sep  7 2023 dmueller@suse.com
- update to 0.40.1:
  * Corrected bad distribution v0.40.0 package.
  * Support for Python 3.11
  * Add the `--print-modified` flag to print out file names of
    modified files when running in in-place mode.
  * Replace the outdated and no-longer-supported lib2to3 with a
    fork of blib2to3
  * Support for Python versions < 3.7 are no longer supported.
* Thu May  4 2023 dmueller@suse.com
- update to 0.33.0:
  * Add a new Python parser to generate logical lines.
  * Added support for `# fmt: on` and `# fmt: off` pragmas.
  * Moved 'pytree' parsing tools into its own subdirectory.
  * Add support for Python 3.10.
  * Format generated dicts with respect to same rules as regular
    dicts
  * Generalized the ending comma heuristic to subscripts.
  * Supports "pyproject.toml" by default.
  * Split line before all comparison operators.
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Sat Jun  4 2022 mcepl@suse.com
- Update to 0.32.0:
  - Look at the 'pyproject.toml' file to see if it contains ignore file information
    for YAPF.
  - New entry point `yapf_api.FormatTree` for formatting lib2to3 concrete
    syntax trees.
  - Change tests to support "pytest".
  - Reformat so that "flake8" is happy.
  - Clean up the FormatToken interface to limit how much it relies upon the
    pytree node object.
  - Rename "unwrapped_line" module to "logical_line."
  - Rename "UnwrappedLine" class to "LogicalLine."
  - Added pyproject extra to install toml package as an optional dependency.
  - Enable `BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF` knob for "pep8" style, so
    method definitions inside a class are surrounded by a single blank line as
    prescribed by PEP8.
  - Fixed the '...' token to be spaced after a colon.
- Fix update-alternatives use.
* Sat Jul 17 2021 dmueller@suse.com
- update to 0.31.0:
  - Add 'BLANK_LINES_BETWEEN_TOP_LEVEL_IMPORTS_AND_VARIABLES' to support setting
  a custom number of blank lines between top-level imports and variable
  definitions.
  - Ignore end of line `# copybara:` directives when checking line length.
  - Do not scan exlcuded directories. Prior versions would scan an exluded
  folder then exclude its contents on a file by file basis. Preventing the
  folder being scanned is faster.
* Fri May 29 2020 mcalabkova@suse.com
- update to 0.30.0
  * Added `SPACES_AROUND_LIST_DELIMITERS`, `SPACES_AROUND_DICT_DELIMITERS`,
    and `SPACES_AROUND_TUPLE_DELIMITERS` to add spaces after the opening
    and before the closing delimiters for lists, dicts, and tuples.
  * Adds `FORCE_MULTILINE_DICT` knob to ensure dictionaries always split,
    even when shorter than the max line length.
  * New knob `SPACE_INSIDE_BRACKETS` to add spaces inside brackets, braces, and
    parentheses.
  * New knob `SPACES_AROUND_SUBSCRIPT_COLON` to add spaces around the subscript /
    slice operator.
  * Renamed "chromium" style to "yapf". Chromium will now use PEP-8 directly.
  * `CONTINUATION_ALIGN_STYLE` with `FIXED` or `VALIGN-RIGHT` now works with
    space indentation.
  * Don't over-indent a parameter list when not needed. But make sure it is
    properly indented so that it doesn't collide with the lines afterwards.
  * Don't split between two-word comparison operators: "is not", "not in", etc.
- Replace nose with pytest
  * not WLOG, some tests get skipped because of capturing stdin
* Tue Feb  4 2020 mcalabkova@suse.com
- update to 0.29.0
  * Add the `--quiet` flag to suppress output. The return code is 1 if there are
    changes, similarly to the `--diff` flag.
  * Catch and report `UnicodeDecodeError` exceptions.
  * Few bugfixes, see CHANGELOG
* Mon Jul 22 2019 tchvatal@suse.com
- Update to 0.28.0:
  * Bugfix release, see CHANGELOG
* Tue Apr  9 2019 mcalabkova@suse.com
- update to version 0.27.0
  * mostly bugfix release, see CHANGELOG for details
* Thu Feb 14 2019 jayvdb@gmail.com
- Remove optional dependency from BuildRequires as no tests fail
  or are skipped when it is missing.
- Remove tests from package
- Update to v0.26.0
  * Many changes to behaviour; see CHANGELOG for details
- from v0.25.0
  * Added `INDENT_BLANK_LINES` knob
  * Support additional file exclude patterns in .yapfignore file
  * Correctly determine if a scope is the last in line
* Wed Oct 24 2018 tchvatal@suse.com
- Version update to 0.24.0:
  * Support for python 3.7
* Wed Aug 29 2018 tchvatal@suse.com
- Version update to 0.23.0:
  * Many changes to behaviour based on CHANGELOG
  * Add various documents/license to distributed tarball
* Sun Mar  4 2018 jengelh@inai.de
- Trim description and focus on the package, not the process.
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
